HermesExponentialBackoff

Struct HermesExponentialBackoff 

pub struct HermesExponentialBackoff { /* private fields */ }
A wrapper around the backoff crate’s exponential backoff configuration.

This struct encapsulates the parameters needed to configure exponential backoff behavior and can be converted into the backoff crate’s ExponentialBackoff type.